@@ -189,8 +189,8 @@ def get_invoker_level(invoker_name):
     # check how much TOKEN the invoker has
     wallet_token_info = Wallet(invoker_name).get_token(TOKEN_NAME)
 
-    invoker_delegationsIn = float(wallet_token_info['delegationsIn'])
-    invoker_stake = float(wallet_token_info['stake'])
+    invoker_delegationsIn = float(wallet_token_info['delegationsIn'] or 0)
+    invoker_stake = float(wallet_token_info['stake'] or 0)
 
     # does invoker meet level 4 requirements?
     min_staked = float(config['AccessLevel4']['MIN_TOKEN_STAKED'])
